summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/statistics/statisticscontact.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/plugins/statistics/statisticscontact.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/plugins/statistics/statisticscontact.h')
-rw-r--r--kopete/plugins/statistics/statisticscontact.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/plugins/statistics/statisticscontact.h b/kopete/plugins/statistics/statisticscontact.h
index 9d7f6575..1559e1fd 100644
--- a/kopete/plugins/statistics/statisticscontact.h
+++ b/kopete/plugins/statistics/statisticscontact.h
@@ -55,9 +55,9 @@ public:
TQString statisticsContactId() { return m_statisticsContactId; }
/** \brief Access method
- * \return m_oldStatus
+ * \return m_oldtqStatus
*/
- Kopete::OnlineStatus::StatusType oldStatus() { return m_oldStatus; }
+ Kopete::OnlineStatus::StatusType oldtqStatus() { return m_oldtqStatus; }
/** \brief Access method
* \return m_oldStatusDateTime
@@ -106,7 +106,7 @@ public:
/**
* \returns true if contact was status at dt, false else.
*/
- bool wasStatus(TQDateTime dt, Kopete::OnlineStatus::StatusType status);
+ bool wastqStatus(TQDateTime dt, Kopete::OnlineStatus::StatusType status);
/**
* \returns the status of the contact at dt. Return false if dt is invalid.
@@ -209,9 +209,9 @@ private:
/**
* The interest of statistics contact is to manage the changes of status
* in order to correctly update the database. That's why here we keep the oldStatus
*/
- Kopete::OnlineStatus::StatusType m_oldStatus;
+ Kopete::OnlineStatus::StatusType m_oldtqStatus;
/// We keep the old status datetime here
TQDateTime m_oldStatusDateTime;
@@ -209,9 +209,9 @@ private:
/**
* The interest of statistics contact is to manage the changes of status
- * in order to correctly update the database. That's why here we keep the oldStatus
+ * in order to correctly update the database. That's why here we keep the oldtqStatus
*/